@@ -111,8 +111,9 @@ options:
       - hello
     default: hello
 notes:
-- Requires the pymongo Python package on the remote host, version 2.4.2+. This
-  can be installed using pip or the OS package manager. @see U(http://api.mongodb.org/python/current/installation.html)
+- Requires the pymongo Python package on the remote host, version 4+.. This
+  can be installed using pip or the OS package manager.
+  @see U(http://api.mongodb.org/python/current/installation.html)
 requirements:
 - pymongo
 '''
@@ -554,8 +555,11 @@ def main():
     debug = module.params['debug']
     cluster_cmd = module.params['cluster_cmd']
 
+    # Count voting members
+    voting_members = sum([1 if not isinstance(m, dict) or m.get("votes", 1) == 1 else 0 for m in members])
+
     if validate and reconfigure is False:
-        if len(members) <= 2 or len(members) % 2 == 0:
+        if len(members) <= 2 or voting_members % 2 == 0:
             module.fail_json(msg="MongoDB Replicaset validation failed. Invalid number of replicaset members.")
         if arbiter_at_index is not None and len(members) - 1 < arbiter_at_index:
             module.fail_json(msg="MongoDB Replicaset validation failed. Invalid arbiter index.")
