@@ -133,10 +133,10 @@ EXAMPLES = '''
         community_list: <your own value>
         state: present # <value in [present, absent]>
         router_communitylist_rule:
-          action: <value in [deny, permit]>
-          id: <integer>
-          match: <string>
-          regexp: <string>
+          id: 0 # Required variable, integer
+          # action: <value in [deny, permit]>
+          # match: <string>
+          # regexp: <string>
 '''
 
 RETURN = '''
@@ -180,23 +180,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/router/community-list/{community-list}/rule',
         '/pm/config/global/obj/router/community-list/{community-list}/rule'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/router/community-list/{community-list}/rule/{rule}',
-        '/pm/config/global/obj/router/community-list/{community-list}/rule/{rule}'
-    ]
-
     url_params = ['adom', 'community-list']
     module_primary_key = 'id'
     module_arg_spec = {
@@ -212,7 +204,6 @@ def main():
                 'match': {'v_range': [['7.0.2', '']], 'type': 'str'},
                 'regexp': {'v_range': [['7.0.2', '']], 'type': 'str'}
             }
-
         }
     }
 
@@ -221,14 +212,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'router_communitylist_rule'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
